## Test `coenocliner` using the `testthat` package

## Setup
library("testthat")

## Runs the tests in inst/tests
test_check("coenocliner")
